==> vscat-1.0.0.tgz: package/tests/highlighting/sources/json/npm-package/results/output.visual-studio-dark.ts <==
// Jest Snapshot v1, https://goo.gl/fbAQLP

exports[`sources suite json language npm-package test visual-studio-dark theme 1`] = `
Object {
  "lines": Array [
    "[48;2;30;30;30m [38;2;133;133;133m 1 │ [39m[38;2;212;212;212m{[39m                                                                         [49m",
    "[48;2;30;30;30m [38;2;133;133;133m 2 │ [39m[38;2;36;37;36m·[39m[38;2;36;37;36m·[39m[38;2;156;220;254m\\"name\\"[39m[38;2;212;212;212m:[39m[38;2;36;37;36m·[39m[38;2;206;145;120m\\"test-package\\"[39m[38;2;212;212;212m,[39m                                                 [49m",
    "[48;2;30;30;30m [38;2;133;133;133m 3 │ [39m[38;2;36;37;36m·[39m[38;2;36;37;36m·[39m[38;2;156;220;254m\\"description\\"[39m[38;2;212;212;212m:[39m[38;2;36;37;36m·[39m[38;2;206;145;120m\\"Some[39m[38;2;36;37;36m·[39m[38;2;206;145;120museful[39m[38;2;36;37;36m·[39m[38;2;206;145;120mpackage[39m[38;2;36;37;36m·[39m[38;2;206;145;120mto[39m[38;2;36;37;36m·[39m[38;2;206;145;120mdo[39m[38;2;36;37;36m·[39m[38;2;206;145;120msome[39m[38;2;36;37;36m·[39m[38;2;206;145;120museful[39m[38;2;36;37;36m·[39m[38;2;206;145;120mstuff[39m[38;2;36;37;36m·[39m[38;2;206;145;120mwith[39m[38;2;36;37;36m·[39m[38;2;206;145;120madvanc[39m[38;2;206;145;120m…[39m[49m",
    "[48;2;30;30;30m [38;2;133;133;133m 4 │ [39m[38;2;36;37;36m·[39m[38;2;36;37;36m·[39m[38;2;156;220;254m\\"version\\"[39m[38;2;212;212;212m:[39m[38;2;36;37;36m·[39m[38;2;206;145;120m\\"1.0.0\\"[39m[38;2;212;212;212m,[39m                                                     [49m",
    "[48;2;30;30;30m [38;2;133;133;133m 5 │ [39m[38;2;36;37;36m·[39m[38;2;36;37;36m·[39m[38;2;156;220;254m\\"private\\"[39m[38;2;212;212;212m:[39m[38;2;36;37;36m·[39m[38;2;86;156;214mtrue[39m[38;2;212;212;212m,[39m                                                        [49m",
    "[48;2;30;30;30m [38;2;133;133;133m 6 │ [39m[38;2;36;37;36m·[39m[38;2;36;37;36m·[39m[38;2;156;220;254m\\"license\\"[39m[38;2;212;212;212m:[39m[38;2;36;37;36m·[39m[38;2;206;145;120m\\"MIT\\"[39m[38;2;212;212;212m,[39m                                                       [49m",
    "[48;2;30;30;30m [38;2;133;133;133m 7 │ [39m[38;2;36;37;36m·[39m[38;2;36;37;36m·[39m[38;2;156;220;254m\\"dependencies\\"[39m[38;2;212;212;212m:[39m[38;2;36;37;36m·[39m[38;2;212;212;212m{[39m                                                       [49m",
    "[48;2;30;30;30m [38;2;133;133;133m 8 │ [39m[38;2;36;37;36m·[39m[38;2;36;37;36m·[39m[38;2;36;37;36m·[39m[38;2;36;37;36m·[39m[38;2;156;220;254m\\"package-1\\"[39m[38;2;212;212;212m:[39m[38;2;36;37;36m·[39m[38;2;206;145;120m\\"1.0.0\\"[39m[38;2;212;212;212m,[39m                                                 [49m",
    "[48;2;30;30;30m [38;2;133;133;133m 9 │ [39m[38;2;36;37;36m·[39m[38;2;36;37;36m·[39m[38;2;36;37;36m·[39m[38;2;36;37;36m·[39m[38;2;156;220;254m\\"package-2\\"[39m[38;2;212;212;212m:[39m[38;2;36;37;36m·[39m[38;2;206;145;120m\\"2.0.0\\"[39m[38;2;212;212;212m,[39m                                                 [49m",
    "[48;2;30;30;30m [38;2;133;133;133m10 │ [39m[38;2;36;37;36m·[39m[38;2;36;37;36m·[39m[38;2;36;37;36m·[39m[38;2;36;37;36m·[39m[38;2;156;220;254m\\"package-3\\"[39m[38;2;212;212;212m:[39m[38;2;36;37;36m·[39m[38;2;206;145;120m\\"3.0.0\\"[39m[38;2;212;212;212m,[39m                                                 [49m",
    "[48;2;30;30;30m [38;2;133;133;133m11 │ [39m[38;2;36;37;36m·[39m[38;2;36;37;36m·[39m[38;2;36;37;36m·[39m[38;2;36;37;36m·[39m[38;2;156;220;254m\\"package-4\\"[39m[38;2;212;212;212m:[39m[38;2;36;37;36m·[39m[38;2;206;145;120m\\"4.0.0\\"[39m[38;2;212;212;212m,[39m                                                 [49m",
    "[48;2;30;30;30m [38;2;133;133;133m12 │ [39m[38;2;36;37;36m·[39m[38;2;36;37;36m·[39m[38;2;36;37;36m·[39m[38;2;36;37;36m·[39m[38;2;156;220;254m\\"package-5\\"[39m[38;2;212;212;212m:[39m[38;2;36;37;36m·[39m[38;2;206;145;120m\\"5.0.0\\"[39m[38;2;212;212;212m,[39m                                                 [49m",
    "[48;2;30;30;30m [38;2;133;133;133m13 │ [39m[38;2;36;37;36m·[39m[38;2;36;37;36m·[39m[38;2;36;37;36m·[39m[38;2;36;37;36m·[39m[38;2;156;220;254m\\"package-6\\"[39m[38;2;212;212;212m:[39m[38;2;36;37;36m·[39m[38;2;206;145;120m\\"6.0.0\\"[39m                                                  [49m",
    "[48;2;30;30;30m [38;2;133;133;133m14 │ [39m[38;2;36;37;36m·[39m[38;2;36;37;36m·[39m[38;2;212;212;212m}[39m                                                                       [49m",
    "[48;2;30;30;30m [38;2;133;133;133m15 │ [39m[38;2;212;212;212m}[39m                                                                         [49m",
    "[48;2;30;30;30m [38;2;133;133;133m16 │ [39m                                                                          [49m",
  ],
  "tokens": Array [
    "
 0 │  0, 1 │ ─────── │ {
───┼───────┼─────────┼──────────────────────────────────────────────────
 1 │  2, 8 │ #9CDCFE │ \\"name\\"
 1 │  8, 9 │ ─────── │ :
 1 │ 10,24 │ #CE9178 │ \\"test-package\\"
 1 │ 24,25 │ ─────── │ ,
───┼───────┼─────────┼──────────────────────────────────────────────────
 2 │  2,15 │ #9CDCFE │ \\"description\\"
 2 │ 15,16 │ ─────── │ :
 2 │ 17,90 │ #CE9178 │ \\"Some useful package to do some useful stuff with advanced capabilities.\\"
 2 │ 90,91 │ ─────── │ ,
───┼───────┼─────────┼──────────────────────────────────────────────────
 3 │  2,11 │ #9CDCFE │ \\"version\\"
 3 │ 11,12 │ ─────── │ :
 3 │ 13,20 │ #CE9178 │ \\"1.0.0\\"
 3 │ 20,21 │ ─────── │ ,
───┼───────┼─────────┼──────────────────────────────────────────────────
 4 │  2,11 │ #9CDCFE │ \\"private\\"
 4 │ 11,12 │ ─────── │ :
 4 │ 13,17 │ #569CD6 │ true
 4 │ 17,18 │ ─────── │ ,
───┼───────┼─────────┼──────────────────────────────────────────────────
 5 │  2,11 │ #9CDCFE │ \\"license\\"
 5 │ 11,12 │ ─────── │ :
 5 │ 13,18 │ #CE9178 │ \\"MIT\\"
 5 │ 18,19 │ ─────── │ ,
───┼───────┼─────────┼──────────────────────────────────────────────────
 6 │  2,16 │ #9CDCFE │ \\"dependencies\\"
 6 │ 16,17 │ ─────── │ :
 6 │ 18,19 │ ─────── │ {
───┼───────┼─────────┼──────────────────────────────────────────────────
 7 │  4,15 │ #9CDCFE │ \\"package-1\\"
 7 │ 15,16 │ ─────── │ :
 7 │ 17,24 │ #CE9178 │ \\"1.0.0\\"
 7 │ 24,25 │ ─────── │ ,
───┼───────┼─────────┼──────────────────────────────────────────────────
 8 │  4,15 │ #9CDCFE │ \\"package-2\\"
 8 │ 15,16 │ ─────── │ :
 8 │ 17,24 │ #CE9178 │ \\"2.0.0\\"
 8 │ 24,25 │ ─────── │ ,
───┼───────┼─────────┼──────────────────────────────────────────────────
 9 │  4,15 │ #9CDCFE │ \\"package-3\\"
 9 │ 15,16 │ ─────── │ :
 9 │ 17,24 │ #CE9178 │ \\"3.0.0\\"
 9 │ 24,25 │ ─────── │ ,
───┼───────┼─────────┼──────────────────────────────────────────────────
10 │  4,15 │ #9CDCFE │ \\"package-4\\"
10 │ 15,16 │ ─────── │ :
10 │ 17,24 │ #CE9178 │ \\"4.0.0\\"
10 │ 24,25 │ ─────── │ ,
───┼───────┼─────────┼──────────────────────────────────────────────────
11 │  4,15 │ #9CDCFE │ \\"package-5\\"
11 │ 15,16 │ ─────── │ :
11 │ 17,24 │ #CE9178 │ \\"5.0.0\\"
11 │ 24,25 │ ─────── │ ,
───┼───────┼─────────┼──────────────────────────────────────────────────
12 │  4,15 │ #9CDCFE │ \\"package-6\\"
12 │ 15,16 │ ─────── │ :
12 │ 17,24 │ #CE9178 │ \\"6.0.0\\"
───┼───────┼─────────┼──────────────────────────────────────────────────
13 │  2, 3 │ ─────── │ }
───┼───────┼─────────┼──────────────────────────────────────────────────
14 │  0, 1 │ ─────── │ }
───┼───────┼─────────┼──────────────────────────────────────────────────
15 │ none  │         │
",
  ],
}
`;

==> vscat-1.0.1.tgz: package/tests/highlighting/sources/json/npm-package/results/output.visual-studio-dark.ts <==
// Jest Snapshot v1, https://goo.gl/fbAQLP

exports[`sources suite json language npm-package test visual-studio-dark theme 1`] = `
Object {
  "lines": Array [
    "[48;2;30;30;30m [38;2;133;133;133m 1 │ [39m[38;2;212;212;212m{[39m                                                                         [49m",
    "[48;2;30;30;30m [38;2;133;133;133m 2 │ [39m[38;2;36;37;36m·[39m[38;2;36;37;36m·[39m[38;2;156;220;254m\\"name\\"[39m[38;2;212;212;212m:[39m[38;2;36;37;36m·[39m[38;2;206;145;120m\\"test-package\\"[39m[38;2;212;212;212m,[39m                                                 [49m",
    "[48;2;30;30;30m [38;2;133;133;133m 3 │ [39m[38;2;36;37;36m·[39m[38;2;36;37;36m·[39m[38;2;156;220;254m\\"description\\"[39m[38;2;212;212;212m:[39m[38;2;36;37;36m·[39m[38;2;206;145;120m\\"Some[39m[38;2;36;37;36m·[39m[38;2;206;145;120museful[39m[38;2;36;37;36m·[39m[38;2;206;145;120mpackage[39m[38;2;36;37;36m·[39m[38;2;206;145;120mto[39m[38;2;36;37;36m·[39m[38;2;206;145;120mdo[39m[38;2;36;37;36m·[39m[38;2;206;145;120msome[39m[38;2;36;37;36m·[39m[38;2;206;145;120museful[39m[38;2;36;37;36m·[39m[38;2;206;145;120mstuff[39m[38;2;36;37;36m·[39m[38;2;206;145;120mwith[39m[38;2;36;37;36m·[39m[38;2;206;145;120madvanc…[39m[49m",
    "[48;2;30;30;30m [38;2;133;133;133m 4 │ [39m[38;2;36;37;36m·[39m[38;2;36;37;36m·[39m[38;2;156;220;254m\\"version\\"[39m[38;2;212;212;212m:[39m[38;2;36;37;36m·[39m[38;2;206;145;120m\\"1.0.0\\"[39m[38;2;212;212;212m,[39m                                                     [49m",
    "[48;2;30;30;30m [38;2;133;133;133m 5 │ [39m[38;2;36;37;36m·[39m[38;2;36;37;36m·[39m[38;2;156;220;254m\\"private\\"[39m[38;2;212;212;212m:[39m[38;2;36;37;36m·[39m[38;2;86;156;214mtrue[39m[38;2;212;212;212m,[39m                                                        [49m",
    "[48;2;30;30;30m [38;2;133;133;133m 6 │ [39m[38;2;36;37;36m·[39m[38;2;36;37;36m·[39m[38;2;156;220;254m\\"license\\"[39m[38;2;212;212;212m:[39m[38;2;36;37;36m·[39m[38;2;206;145;120m\\"MIT\\"[39m[38;2;212;212;212m,[39m                                                       [49m",
    "[48;2;30;30;30m [38;2;133;133;133m 7 │ [39m[38;2;36;37;36m·[39m[38;2;36;37;36m·[39m[38;2;156;220;254m\\"dependencies\\"[39m[38;2;212;212;212m:[39m[38;2;36;37;36m·[39m[38;2;212;212;212m{[39m                                                       [49m",
    "[48;2;30;30;30m [38;2;133;133;133m 8 │ [39m[38;2;36;37;36m·[39m[38;2;36;37;36m·[39m[38;2;36;37;36m·[39m[38;2;36;37;36m·[39m[38;2;156;220;254m\\"package-1\\"[39m[38;2;212;212;212m:[39m[38;2;36;37;36m·[39m[38;2;206;145;120m\\"1.0.0\\"[39m[38;2;212;212;212m,[39m                                                 [49m",
    "[48;2;30;30;30m [38;2;133;133;133m 9 │ [39m[38;2;36;37;36m·[39m[38;2;36;37;36m·[39m[38;2;36;37;36m·[39m[38;2;36;37;36m·[39m[38;2;156;220;254m\\"package-2\\"[39m[38;2;212;212;212m:[39m[38;2;36;37;36m·[39m[38;2;206;145;120m\\"2.0.0\\"[39m[38;2;212;212;212m,[39m                                                 [49m",
    "[48;2;30;30;30m [38;2;133;133;133m10 │ [39m[38;2;36;37;36m·[39m[38;2;36;37;36m·[39m[38;2;36;37;36m·[39m[38;2;36;37;36m·[39m[38;2;156;220;254m\\"package-3\\"[39m[38;2;212;212;212m:[39m[38;2;36;37;36m·[39m[38;2;206;145;120m\\"3.0.0\\"[39m[38;2;212;212;212m,[39m                                                 [49m",
    "[48;2;30;30;30m [38;2;133;133;133m11 │ [39m[38;2;36;37;36m·[39m[38;2;36;37;36m·[39m[38;2;36;37;36m·[39m[38;2;36;37;36m·[39m[38;2;156;220;254m\\"package-4\\"[39m[38;2;212;212;212m:[39m[38;2;36;37;36m·[39m[38;2;206;145;120m\\"4.0.0\\"[39m[38;2;212;212;212m,[39m                                                 [49m",
    "[48;2;30;30;30m [38;2;133;133;133m12 │ [39m[38;2;36;37;36m·[39m[38;2;36;37;36m·[39m[38;2;36;37;36m·[39m[38;2;36;37;36m·[39m[38;2;156;220;254m\\"package-5\\"[39m[38;2;212;212;212m:[39m[38;2;36;37;36m·[39m[38;2;206;145;120m\\"5.0.0\\"[39m[38;2;212;212;212m,[39m                                                 [49m",
    "[48;2;30;30;30m [38;2;133;133;133m13 │ [39m[38;2;36;37;36m·[39m[38;2;36;37;36m·[39m[38;2;36;37;36m·[39m[38;2;36;37;36m·[39m[38;2;156;220;254m\\"package-6\\"[39m[38;2;212;212;212m:[39m[38;2;36;37;36m·[39m[38;2;206;145;120m\\"6.0.0\\"[39m                                                  [49m",
    "[48;2;30;30;30m [38;2;133;133;133m14 │ [39m[38;2;36;37;36m·[39m[38;2;36;37;36m·[39m[38;2;212;212;212m}[39m                                                                       [49m",
    "[48;2;30;30;30m [38;2;133;133;133m15 │ [39m[38;2;212;212;212m}[39m                                                                         [49m",
    "[48;2;30;30;30m [38;2;133;133;133m16 │ [39m                                                                          [49m",
  ],
  "tokens": Array [
    "
 0 │  0, 1 │ ─────── │ {
───┼───────┼─────────┼──────────────────────────────────────────────────
 1 │  2, 8 │ #9CDCFE │ \\"name\\"
 1 │  8, 9 │ ─────── │ :
 1 │ 10,24 │ #CE9178 │ \\"test-package\\"
 1 │ 24,25 │ ─────── │ ,
───┼───────┼─────────┼──────────────────────────────────────────────────
 2 │  2,15 │ #9CDCFE │ \\"description\\"
 2 │ 15,16 │ ─────── │ :
 2 │ 17,90 │ #CE9178 │ \\"Some useful package to do some useful stuff with advanced capabilities.\\"
 2 │ 90,91 │ ─────── │ ,
───┼───────┼─────────┼──────────────────────────────────────────────────
 3 │  2,11 │ #9CDCFE │ \\"version\\"
 3 │ 11,12 │ ─────── │ :
 3 │ 13,20 │ #CE9178 │ \\"1.0.0\\"
 3 │ 20,21 │ ─────── │ ,
───┼───────┼─────────┼──────────────────────────────────────────────────
 4 │  2,11 │ #9CDCFE │ \\"private\\"
 4 │ 11,12 │ ─────── │ :
 4 │ 13,17 │ #569CD6 │ true
 4 │ 17,18 │ ─────── │ ,
───┼───────┼─────────┼──────────────────────────────────────────────────
 5 │  2,11 │ #9CDCFE │ \\"license\\"
 5 │ 11,12 │ ─────── │ :
 5 │ 13,18 │ #CE9178 │ \\"MIT\\"
 5 │ 18,19 │ ─────── │ ,
───┼───────┼─────────┼──────────────────────────────────────────────────
 6 │  2,16 │ #9CDCFE │ \\"dependencies\\"
 6 │ 16,17 │ ─────── │ :
 6 │ 18,19 │ ─────── │ {
───┼───────┼─────────┼──────────────────────────────────────────────────
 7 │  4,15 │ #9CDCFE │ \\"package-1\\"
 7 │ 15,16 │ ─────── │ :
 7 │ 17,24 │ #CE9178 │ \\"1.0.0\\"
 7 │ 24,25 │ ─────── │ ,
───┼───────┼─────────┼──────────────────────────────────────────────────
 8 │  4,15 │ #9CDCFE │ \\"package-2\\"
 8 │ 15,16 │ ─────── │ :
 8 │ 17,24 │ #CE9178 │ \\"2.0.0\\"
 8 │ 24,25 │ ─────── │ ,
───┼───────┼─────────┼──────────────────────────────────────────────────
 9 │  4,15 │ #9CDCFE │ \\"package-3\\"
 9 │ 15,16 │ ─────── │ :
 9 │ 17,24 │ #CE9178 │ \\"3.0.0\\"
 9 │ 24,25 │ ─────── │ ,
───┼───────┼─────────┼──────────────────────────────────────────────────
10 │  4,15 │ #9CDCFE │ \\"package-4\\"
10 │ 15,16 │ ─────── │ :
10 │ 17,24 │ #CE9178 │ \\"4.0.0\\"
10 │ 24,25 │ ─────── │ ,
───┼───────┼─────────┼──────────────────────────────────────────────────
11 │  4,15 │ #9CDCFE │ \\"package-5\\"
11 │ 15,16 │ ─────── │ :
11 │ 17,24 │ #CE9178 │ \\"5.0.0\\"
11 │ 24,25 │ ─────── │ ,
───┼───────┼─────────┼──────────────────────────────────────────────────
12 │  4,15 │ #9CDCFE │ \\"package-6\\"
12 │ 15,16 │ ─────── │ :
12 │ 17,24 │ #CE9178 │ \\"6.0.0\\"
───┼───────┼─────────┼──────────────────────────────────────────────────
13 │  2, 3 │ ─────── │ }
───┼───────┼─────────┼──────────────────────────────────────────────────
14 │  0, 1 │ ─────── │ }
───┼───────┼─────────┼──────────────────────────────────────────────────
15 │ none  │         │
",
  ],
}
`;
